@@ -43,11 +43,12 @@ pub mod state;
 
 pub mod free_lifetimes;
 
+pub use dyn_context_macro::State;
 pub use dyn_context_macro::Stop;
 
 #[cfg(test)]
 mod test {
-    use crate::{Stop, free_lifetimes, impl_stop};
+    use crate::{State, Stop, free_lifetimes, impl_stop_and_appropriate_drop};
     use crate::state::{SelfState, State, StateExt, StateRefMut};
     use core::mem::replace;
     use core::ops::Deref;
@@ -152,7 +153,7 @@ mod test {
 
     impl SelfState for TestStop { }
 
-    impl_stop!(for TestStop {
+    impl_stop_and_appropriate_drop!(for TestStop {
         fn is_stopped(&self) -> bool { self.stopped }
 
         fn stop(state: &mut dyn State) {
@@ -171,4 +172,20 @@ mod test {
         #[allow(dead_code)]
         i: i32
     }
+
+    struct A;
+    impl SelfState for A { }
+    struct B;
+    impl SelfState for B { }
+
+    #[derive(State)]
+    #[state(part)]
+    struct TestDerive {
+        #[state]
+        a: A,
+        #[state]
+        b: B,
+        #[state(part)]
+        c: i32,
+    }
 }
